set more off
clear

do pocc8090
clear
use mcsui_hh2


* gender
rename crespsex sex
lab define sex 1 "male" 2 "female"
lab val sex sex
tab sex

* label the race variable
gen race=gicrace
recode race 1=2 2=3 3=4 4=1
lab define race 1 "white" 2 "black" 3 "hispanic" 4 "asian" 5 "other" 9 "missing"
lab val race race

tab race
drop if race>5

* label the city variable
lab define city 1 "detroit" 2 "atlanta" 3 "los angeles" 4 "boston"
lab val city city

tab city

* education
gen edyrs=eeduyrs
recode edyrs 95/100=.
sum edyrs
tab race, sum(edyrs)


* first do wages

tab wageflag

replace fhrwage=. if wageflag>0

sum fhrwage
* fhrwage is hourly wages

tab race, sum(fhrwage)

sort caseid
save temp, replace

keep hsexper* hrelper* hmarper* hneiper* hhlpper* hcntper* caseid /*
*/ hjobper* hwelper* heduper* hracper* race sex city hnumnetw 

des



reshape long hsexper hrelper hmarper hneiper hhlpper hcntper /*
*/ hjobper hwelper heduper hracper, i(caseid) j(friend)

des

drop if city==1
* social network questions were not asked in Detroit

* drop if crace==5
recode hracper 7=5 8=5 9=5

drop if hrelper==0
* this commands gets rid of missing cases--"logical skips"

* drop if hrelper==1
**** check

recode hjob 7=5 8=5 9=.
recode heduper 7=. 8=. 9=.
recode hmarper 8=. 9=.
mvdecode hrelper hneiper hhlpper hcntper hwelper, mv(6)
mvdecode hrelper hneiper hhlpper hcntper hwelper, mv(8)
mvdecode hrelper hneiper hhlpper hcntper hwelper, mv(9)


lab val hracper race


lab define hrelper 1 "relative" 2 "friend" 3 "co-worker" 4 "other" 
recode hrelper 5/9=4
lab val hrelper hrelper

tab friend

tab hrelper

tab race hracper if hrelper>1, row nofreq

sum heduper
recode heduper 1=6 2=10 3=12 4=14 5=15 6=16 
recode hjob 5=0
recode hwelper 5=0
recode hhlpper 5=0
recode hcntper 5=0

gen f_w=hracper==1
gen f_b=hracper==2
gen f_h=hracper==3
gen f_a=hracper==4

recode hsexper 2=1 1=0 7/9=.
* i.e., 1=female

save friends, replace

collapse (mean) f_sex=hsexper f_ed=heduper f_wel=hwelper f_job=hjob /*
*/ f_hlp=hhlpper f_cnt=hcntper (sum) f_*, by(caseid) 


sort caseid

merge caseid using temp
tab _merge

for var f_*: replace X=. if _merge==2


* job contacts

recode ffindhow 7/9=. 0=.
lab define ffindhow 1 "friends or relatives" 2 "other persons" 3 "newspaper" 5 "other"
lab val ffindhow ffindhow

recode fwhohelp 7/9=. 0=.
lab define fwhohelp 1 "relative" 2 "friend" 3 "acquiantance" 4 "someone else"
lab val fwhohelp fwhohelp

recode fhlprace 5/9=. 0=.
lab val fhlprace race

recode fhlpsex 0=. 7/9=.
lab val fhlpsex sex

tab ffindhow
tab fwhohelp

tab race fhlprace, row

tab sex fhlpsex, row


gen wgt=wpstpere


save mcsui2, replace
*/
use mcsui2


keep if city>1

gen ser=flstsrch>0 & flstsrch<3
gen frnd=ffindhow==1 | ffindhow==2
gen frnd2=fwhohelp>1 & fwhohelp~=.

tab ffindhow frnd
tab fwhohelp frnd

keep if ser==1

capture drop _merge
rename foccup occ
sort occ
merge occ using occf_nlsy90
tab _merge
drop if _merge==2

sort occ
capture drop _merge
merge occ using prestige90
tab _merge
drop _merge
sum prestige 

gen occf=frndocc/n
gen lnwage=ln(fhrwage)

des
drop if fhrwage<3

sum lnwage race sex edyrs f_*

egen r=rmiss(race lnwage occf sex edyrs f_*)
sort r
sum lnwage race sex edyrs f_* if lnwage~=.

drop if lnwage==.
drop if sex==.
drop if edyrs==.
drop if r>0

* table 0
for var fschfnds fschrela fschnews fschunon fschstat fschschl fschwant /*
*/ fschpriv fschwalk fschtemp fschsend fschothr: recode X 0=. 5=0 7/9=.



gen fschinf=fschfnds==1 | fschrela==1
tab fschinf

egen totm=rsum(fschfnds fschrela fschnews fschunon fschstat fschschl fschwant /*
*/ fschpriv fschwalk fschsend fschtemp fschothr)
egen totm2=rsum(fschnews fschunon fschstat fschschl fschwant /*
*/ fschpriv fschwalk fschsend fschtemp fschothr)
lab var totm2 "# of methods other than friends"


sum frnd frnd2 [aw=wgt]
tab totm2
tab totm2 if fschfnds==1
tab totm2 if fschfnds==1 [aw=wgt]
* this gives the % using contacts to search

tab totm2 [aw=wgt], nofreq
tab totm2 if fschfnds==1 [aw=wgt], nofreq
tab totm2 if fschinf==1 [aw=wgt]
* this gives the percentage of individuals who searched via informal methods
* who also used at least one other method

save network02, replace

* reviewer A

tab fschinf [aw=wgt]
tab totm2 if fschinf==1 [aw=wgt]
sum fschfnds-fschothr if fschinf==0

xi: reg totm2   i.sex i.race  edyrs i.city f_ed f_job f_wel /*                 
*/  occf [aw=wgt] if fschinf==1
outreg using reva, se replace
xi: reg totm2   i.sex i.race  edyrs i.city f_ed f_job f_wel /*
*/  occf [aw=wgt] 
outreg using reva, se append
xi: logit fschn i.sex i.race  edyrs i.city f_ed f_job f_wel /*
*/  occf [aw=wgt] if fschinf==1 
outreg using reva, se append
xi: logit fschinf i.sex i.race  edyrs i.city f_ed f_job f_wel /*
*/  occf [aw=wgt] 
xi: logit fschinf i.sex i.race  edyrs i.city f_ed f_job f_wel /* 
*/  [aw=wgt]    


xi: logit frnd [aw=wgt]
xi: logit frnd i.sex i.race  edyrs i.city f_*  [aw=wgt]
xi: logit frnd i.sex i.race  edyrs i.city f_*  occf [aw=wgt]
xi: logit frnd2 i.sex i.race  edyrs i.city f_*  occf [aw=wgt]

xi: logit frnd i.sex i.race  edyrs i.city f_ed f_job f_wel f_sex f_cnt f_hlp occf [aw=wgt]
xi: logit frnd2 i.sex i.race  edyrs i.city f_ed f_job f_wel f_sex f_cnt f_hlp occf [aw=wgt]

xi i.sex i.race i.city
 
sum frnd _I* edyrs f_ed f_job f_wel f_sex occf [aw=wgt]


xi: logit frnd i.sex i.race  edyrs i.city f_ed f_job f_wel occf [aw=wgt]
outreg using network02, se replace

xi: logit frnd2 i.sex i.race  edyrs i.city f_ed f_job f_wel occf [aw=wgt]

xi: reg lnwage frnd i.sex i.race  edyrs i.city [aw=wgt]
outreg using network02, se append

xi: reg lnwage i.sex i.race  edyrs i.city f_ed f_job f_wel occf [aw=wgt]
outreg using network02, se append

xi: reg lnwage  i.sex i.race  edyrs i.city i.frnd*f_ed i.frnd*f_job i.frnd*f_wel occf [aw=wgt]
outreg using network03, se replace

xi: reg lnwage  i.sex i.race  edyrs i.city f_ed f_job f_wel f_sex f_cnt f_hlp occf [aw=wgt]



xi: reg prestige i.sex i.race  edyrs i.city f_ed f_job f_wel occf [aw=wgt]
outreg using p_network02, se replace
xi: reg prestige frnd i.sex i.race  edyrs i.city [aw=wgt]
outreg using p_network02, se append
xi: reg lnwage  i.sex i.race  edyrs i.city i.frnd*f_ed i.frnd*f_job i.frnd*f_wel occf [aw=wgt]
outreg using p_network03, se replace


save temp, replace

/*

keep caseid lnwage frnd sex crace edyrs city f_* wgt
sort caseid
merge caseid using temp1
save temp2, replace


/*
xi: regress fhrwage i.race [w=wgt]
outreg using mod1, se replace

xi: regress fhrwage i.race i.sex [w=wgt]
outreg using mod1, se append
 
xi: regress fhrwage i.race i.sex edyrs [w=wgt]
outreg using mod1, se append

xi: regress fhrwage i.race i.sex edyrs f_ed [w=wgt]
outreg using mod1, se append 

set more on
